@@ -46,6 +46,7 @@ from Tensile.KernelWriterBase import KernelWriterBase
 from Tensile.KernelWriterSource import KernelWriterSource
 from Tensile.SolutionStructs import ProblemSizes, Solution
 from Tensile.Utilities.ConditionalImports import yamlLoader
+from Tensile.Utilities.Toolchain import ToolchainDefaults, validateToolchain
 
 mylogger = logging.getLogger()
 
@@ -273,7 +274,7 @@ def test_findLogicFiles():
 
         result = tcl.findLogicFiles(baseDir, logicArchs, lazyLoading, experimentalDir)
         expected = findLogicFiles_oldLogic(baseDir, logicArchs, lazyLoading, experimentalDir)
-        return result == expected
+        return set(result) == set(expected)
 
     def outputMatchesOldLogic2():
         baseDir, lazyLoading, experimentalDir = setup()
@@ -286,7 +287,7 @@ def test_findLogicFiles():
 
         result = tcl.findLogicFiles(baseDir, logicArchs, lazyLoading, experimentalDir)
         expected = findLogicFiles_oldLogic(baseDir, logicArchs, lazyLoading, experimentalDir)
-        return result == expected
+        return set(result) == set(expected)
 
     def outputMatchesOldLogic3():
         baseDir, lazyLoading, experimentalDir = setup()
@@ -297,7 +298,7 @@ def test_findLogicFiles():
 
         result = tcl.findLogicFiles(baseDir, logicArchs, lazyLoading, experimentalDir)
         expected = findLogicFiles_oldLogic(baseDir, logicArchs, lazyLoading, experimentalDir)
-        return result == expected
+        return set(result) == set(expected)
 
     def verifyYamlAndYml():
         baseDir, lazyLoading, experimentalDir = setup()
@@ -537,7 +538,26 @@ def setupSolutionsAndKernels(
     unittestPath,
 ) -> Tuple[List[Solution], List[Solution], KernelWriterAssembly, KernelWriterSource]:
     """Reusable logic for setting up testable solutions and kernels"""
-    Common.assignGlobalParameters({})
+
+    (cxxCompiler, cCompiler, assembler, offloadBundler, hipconfig, deviceEnumerator) = (
+        validateToolchain(
+            ToolchainDefaults.CXX_COMPILER,
+            ToolchainDefaults.C_COMPILER,
+            ToolchainDefaults.ASSEMBLER,
+            ToolchainDefaults.OFFLOAD_BUNDLER,
+            ToolchainDefaults.HIP_CONFIG,
+            ToolchainDefaults.DEVICE_ENUMERATOR,
+        )
+    )
+    params = {
+        "CxxCompiler": cxxCompiler,
+        "CCompiler": cCompiler,
+        "Assembler": assembler,
+        "OffloadBundler": offloadBundler,
+        "HipConfig": hipconfig,
+        "ROCmAgentEnumeratorPath": deviceEnumerator,
+    }
+    Common.assignGlobalParameters(params)
     _, _, _, _, _, lib = LibraryIO.parseLibraryLogicFile(
         unittestPath.parent / "test_data" / "unit" / "aldebaran_Cijk_AlikC_Bljk_ZB_GB.yaml"
     )
@@ -557,7 +577,7 @@ def test_prepAsm(setupSolutionsAndKernels):
     def testLinux():
         tcl.prepAsm(kernelWriterAssembly, True, Path("no-commit-prep-asm"), (9, 0, 10), 1)
 
-        expected = """#!/bin/sh 
+        expected = """#!/bin/sh
 # usage: asm-new.sh kernelName(no extension) [--wave32]
 f=$1
 shift
@@ -597,7 +617,7 @@ if %arg2% EQU --wave32 set /A wave=32
 set h=gfx90a
 if %wave% == 32 (/opt/rocm/bin/amdclang++ -x assembler -target amdgcn-amd-amdhsa -mcode-object-version=4 -mcpu=gfx90a -mno-wavefrontsize64 -c -o %f%.o %f%.s) else (/opt/rocm/bin/amdclang++ -x assembler -target amdgcn-amd-amdhsa -mcode-object-version=4 -mcpu=gfx90a -mwavefrontsize64 -c -o %f%.o %f%.s)
 /opt/rocm/bin/amdclang++ -target amdgcn-amd-amdhsa -Xlinker --build-id -o %f%.co %f%.o
-copy %f%.co ..\..\..\library\%f%_%h%.co
+copy %f%.co ..\\..\\..\library\%f%_%h%.co
 """
 
         with open(buildPath / "assembly" / "asm-new.bat", "r") as f:
